import numpy as np
import pandas as pd
from glob import glob
import matplotlib
import matplotlib.pyplot as plt
import datetime
from matplotlib.font_manager import FontProperties


files = glob('predata/csv/*.csv')

df = pd.concat(
    (pd.read_csv(file, usecols=['日期', '入出境總人數_小計'], dtype={'日期': str, '入出境總人數_小計': str}, index_col='日期') for file in files))


df = df.dropna()
df['入出境總人數_小計'] = pd.to_numeric(df['入出境總人數_小計'])
df['日期'] = pd.to_datetime(df.index, format='%Y%m%d')

df['Year'] = df['日期'].dt.year
df['Month'] = df['日期'].dt.month
month = df['Month'].unique()
print(month)

Year2018 = "2018"
isYear2018 = (df['Year'] == int(Year2018))
df2018 = df[isYear2018]
df2018 = df2018.groupby(['Year', 'Month']).sum()

Year2019 = "2019"
isYear2019 = (df['Year'] == int(Year2019))
df2019 = df[isYear2019]
df2019 = df2019.groupby(['Year', 'Month']).sum()

Year2020 = "2020"
isYear2020 = (df['Year'] == int(Year2020))
df2020 = df[isYear2020]
df2020 = df2020.groupby(['Year', 'Month']).sum()

Year2021 = "2021"
isYear2021 = (df['Year'] == int(Year2021))
df2021 = df[isYear2021]
df2021 = df2021.groupby(['Year', 'Month']).sum()


print(df)

# chart = df.plot(kind='bar')
x = np.arange(12)
width = 0.22
plt.bar(x, df2018['入出境總人數_小計'], width=width, label='2018入出境總人數')
plt.bar(x+width, df2019['入出境總人數_小計'], width=width, label='2019入出境總人數')
plt.bar(x+width*2, df2020['入出境總人數_小計'], width=width, label='2020入出境總人數')
plt.bar(x+width*3, df2021['入出境總人數_小計'], width=width, label='2021入出境總人數')
plt.xticks(x + width, month, fontproperties=font, fontsize=50)
font = FontProperties(fname=r'Font.ttf')


# for label in chart.get_xticklabels():
#     label.set_fontproperties(font)  # 設定字體
# must set in top
plt.rcParams.update({'font.size': 44, "figure.figsize": (80, 30)})
plt.title('2018-2021年出入境人口', fontproperties=font)  # 圖表標題
plt.xlabel('月份', fontproperties=font)  # x軸說明文字
plt.ylabel('人數', fontproperties=font)  # y軸說明文字
plt.legend(prop=font)  # 圖例
plt.style.use('dark_background')  # 黑色主題

plt.show()  # render
